@@ -11,7 +11,7 @@ module.exports = function(files, expression, sandbox, callback) {
       .on("data", function(chunk) { chunks.push(chunk); })
       .on("end", function() {
         var error, result;
-        try { result = vm.runInNewContext(chunks.join("") + ";" + expression, sandbox); }
+        try { result = vm.runInNewContext(chunks.join("") + ";(" + expression + ")", sandbox); }
         catch (e) { error = e; }
         callback(error, result);
       });
